aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/DeveloperModule.cs
diff options
context:
space:
mode:
Diffstat (limited to 'Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/DeveloperModule.cs')
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/DeveloperModule.cs10
1 files changed, 8 insertions, 2 deletions
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/DeveloperModule.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/DeveloperModule.cs
index 9ac8de012..166a3212a 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/DeveloperModule.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/DeveloperModule.cs
@@ -35,9 +35,15 @@ namespace Tango.MachineStudio.Developer
public override BitmapSource Image => ResourceHelper.GetImageFromResources("Images/developer.jpg");
/// <summary>
/// Gets the module entry point view.
/// </summary>
- public override FrameworkElement MainView => new MainView();
+ public override Type MainViewType
+ {
+ get
+ {
+ return typeof(MainView);
+ }
+ }
/// <summary>
/// Gets the permission required to see and load this module.
@@ -35,9 +35,15 @@ namespace Tango.MachineStudio.Developer
public override BitmapSource Image => ResourceHelper.GetImageFromResources("Images/developer.jpg");
/// <summary>
- /// Gets the module entry point view.
+ /// Gets the module entry point view type.
/// </summary>